*********************
WireViz-Web changelog
*********************


in progress
===========
- Use version number from ``wireviz_web.__version__``
- Add software tests
- Add CI with GitHub Actions
- Use ``flask-restx`` instead of ``flask-restplus``
- Parametrize ``wireviz_web.cli``
- Run coverage testing on CI, with Codecov
- Generalize API/core routines
- Adjust error response texts
- Respond with JSON body on 404 errors
- Improve inline documentation
- Run Black and isort
- Move PlantUML API endpoint to /plantuml prefix


2021-01-06 0.0.0
================
- Initial import
